package me.schaertl.graphcli;

import org.eclipse.rdf4j.model.Statement;
import org.eclipse.rdf4j.repository.RepositoryConnection;
import org.eclipse.rdf4j.repository.RepositoryResult;

import java.util.ArrayList;
import java.util.List;

public class Main {
    private static final String SERVER_URL = "http://rdf:7200";
    private static final String REPOSITORY = "dump";
    private static final int LIMIT = 100;

    private static void hello() throws Exception {
        try (final GraphDB db = new GraphDB(SERVER_URL, REPOSITORY)) {
            final RepositoryConnection connection = db.connection();

            final RepositoryResult<Statement> result = connection.getStatements(null, ULO.INDUCTIVE_ON, null, true);

            for (Statement s : take(result, LIMIT)) {
                System.out.printf("%s INDUCTIVE ON %s", s.getSubject(), s.getObject());
            }
        }
    }

    /**
     * Return the first n results from result.
     *
     * @param result The result from which the results will be returned.
     * @param n The maximum number of items to return.
     */
    private static List<Statement> take(RepositoryResult<Statement> result, int n) {
        final List<Statement> l = new ArrayList<>(n);

        for (int i = 0; i < LIMIT && result.hasNext(); i++) {
            final Statement s = result.next();
            l.add(s);
        }

        return l;
    }

    public static void main(String[] args) throws Exception {
        Main.hello();
        System.out.println("done running the program");
    }
}
